<?php

namespace App\Http\Controllers;

use Error;
use Carbon\Carbon;
use App\Models\Order;
use App\Models\Payment;
use App\Models\PayChanguPayment;
use App\Models\Restaurant;
use Illuminate\Http\Request;
use App\Events\SendNewOrderReceived;
use App\Notifications\SendOrderBill;
use Illuminate\Support\Facades\Http;
use Illuminate\Support\Facades\Notification;

class PayChanguController extends Controller
{
    public function orderPayment()
    {
        $payment = PayChanguPayment::findOrFail(request()->order_payment);
        $paymentGateway = $payment->order->branch->restaurant->paymentGateways;

        $tx_ref = 'TX_' . uniqid();
        $payment->tx_ref = $tx_ref;
        $payment->save();

        return response()->json([
            'public_key' => $paymentGateway->paychangu_public_key,
            'tx_ref' => $tx_ref,
            'amount' => floatval($payment->amount),
            'currency' => $payment->order->branch->restaurant->currency->currency_code,
            'callback_url' => route('paychangu.success'),
            'return_url' => module_enabled('Subdomain') ? url('/') : route('shop_restaurant', ['hash' => $payment->order->branch->restaurant->hash]),
            'customer' => [
                'email' => $payment->order->customer?->email ?? 'guest@example.com',
                'first_name' => $payment->order->customer?->first_name ?? 'Guest',
                'last_name' => $payment->order->customer?->last_name ?? 'User'
            ],
            'customization' => [
                'title' => 'Order #' . $payment->order->order_number,
                'description' => 'Payment for order #' . $payment->order->order_number
            ]
        ]);
    }

    public function success(Request $request)
    {
        $payment = PayChanguPayment::where('tx_ref', $request->tx_ref)->firstOrFail();
        $paymentGateway = $payment->order->branch->restaurant->paymentGateways;

        try {
            $response = Http::withToken($paymentGateway->paychangu_secret_key)
                ->get("https://api.paychangu.com/verify-payment/{$request->tx_ref}");

            if ($response->successful() && $response->json('data.status') === 'success') {
                $payment->payment_reference = $response->json('data.reference');
                $payment->payment_status = 'completed';
                $payment->payment_date = now()->toDateTimeString();
                $payment->save();

                Payment::create([
                    'order_id' => $payment->order_id,
                    'payment_method' => 'paychangu',
                    'amount' => $payment->amount,
                    'transaction_id' => $payment->payment_reference
                ]);

                $order = Order::find($payment->order_id);
                $order->amount_paid = $payment->amount;
                $order->status = 'paid';
                $order->save();

                $this->sendNotifications($order);

                return redirect()->route('order_success', $payment->order_id);
            } else {
                $payment->payment_status = 'declined';
                $payment->payment_error_response = $response->body();
                $payment->save();

                return redirect()->route('shop_restaurant', ['hash' => $payment->order->branch->restaurant->hash])
                    ->with('error', 'Payment verification failed. Please try again.');
            }
        } catch (Error $e) {
            $payment->payment_status = 'declined';
            $payment->payment_error_response = $e->getMessage();
            $payment->save();

            return redirect()->route('shop_restaurant', ['hash' => $payment->order->branch->restaurant->hash])
                ->with('error', 'An error occurred during payment verification. Please try again.');
        }
    }

    protected function sendNotifications($order)
    {
        event(new SendNewOrderReceived($order));
        
        if ($order->customer && $order->customer->email) {
            Notification::send($order->customer, new SendOrderBill($order));
        }
    }
} 