<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    /**
     * Run the migrations.
     */
    public function up(): void
    {
        // Add PayChangu fields to payment_gateway_credentials
        Schema::table('payment_gateway_credentials', function (Blueprint $table) {
            $table->text('paychangu_public_key')->nullable();
            $table->text('paychangu_secret_key')->nullable();
            $table->boolean('paychangu_status')->default(false);
        });

        // Add PayChangu fields to superadmin_payment_gateways
        Schema::table('superadmin_payment_gateways', function (Blueprint $table) {
            $table->enum('paychangu_type', ['test', 'live'])->default('test');
            
            $table->text('test_paychangu_public_key')->nullable();
            $table->text('test_paychangu_secret_key')->nullable();
            $table->text('paychangu_test_webhook_key')->nullable();

            $table->text('live_paychangu_public_key')->nullable();
            $table->text('live_paychangu_secret_key')->nullable();
            $table->text('paychangu_live_webhook_key')->nullable();

            $table->boolean('paychangu_status')->default(false);
        });

        // Add paychangu to payment_method enum in payments table
        Schema::table('payments', function (Blueprint $table) {
            \DB::statement("ALTER TABLE payments MODIFY COLUMN payment_method ENUM('cash', 'upi', 'card', 'due', 'stripe', 'razorpay', 'paychangu') DEFAULT 'cash'");
        });
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        // Remove PayChangu fields from payment_gateway_credentials
        Schema::table('payment_gateway_credentials', function (Blueprint $table) {
            $table->dropColumn([
                'paychangu_public_key',
                'paychangu_secret_key',
                'paychangu_status'
            ]);
        });

        // Remove PayChangu fields from superadmin_payment_gateways
        Schema::table('superadmin_payment_gateways', function (Blueprint $table) {
            $table->dropColumn([
                'paychangu_type',
                'test_paychangu_public_key',
                'test_paychangu_secret_key',
                'paychangu_test_webhook_key',
                'live_paychangu_public_key',
                'live_paychangu_secret_key',
                'paychangu_live_webhook_key',
                'paychangu_status'
            ]);
        });

        // Revert payment_method enum in payments table
        Schema::table('payments', function (Blueprint $table) {
            \DB::statement("ALTER TABLE payments MODIFY COLUMN payment_method ENUM('cash', 'upi', 'card', 'due', 'stripe', 'razorpay') DEFAULT 'cash'");
        });
    }
}; 